<?php
/**
 * Add theme options in Customizer.
 *
 * @package WEN_Associate
 */

add_filter( 'wen_associate_theme_options_args', 'wen_associate_setting_theme_options_args' );

if ( ! function_exists( 'wen_associate_setting_theme_options_args' ) ) :

	/**
	 * Add settings options.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args Theme option arguments.
	 * @return array Modified theme option arguments.
	 */
	function wen_associate_setting_theme_options_args( $args ) {

		// Header Section.
		$args['panels']['theme_option_panel']['sections']['section_header'] = array(
			'title'    => __( 'Header Options', 'wen-associate' ),
			'priority' => 40,
			'fields'   => array(
				'header_layout' => array(
					'title'             => __( 'Header Layout', 'wen-associate' ),
					'type'              => 'radio-image',
					'choices'           => wen_associate_get_header_layout_options(),
					'sanitize_callback' => 'sanitize_key',
					),
				'show_site_title' => array(
					'title'   => __( 'Show Site Title', 'wen-associate' ),
					'type'    => 'checkbox',
					),
				'show_tagline' => array(
					'title'             => __( 'Show Tagline', 'wen-associate' ),
					'type'              => 'checkbox',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					),
				'enable_top_bar' => array(
					'title'             => __( 'Enable Top Bar', 'wen-associate' ),
					'type'              => 'checkbox',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					),
				'contact_number' => array(
					'title'             => __( 'Contact Number', 'wen-associate' ),
					'type'              => 'text',
					'sanitize_callback' => 'sanitize_text_field',
					'active_callback'   => 'wen_associate_is_header_top_bar_active',
					),
				'contact_email' => array(
					'title'             => __( 'Contact Email', 'wen-associate' ),
					'type'              => 'text',
					'sanitize_callback' => 'sanitize_text_field',
					'active_callback'   => 'wen_associate_is_header_top_bar_active',
					),
				'social_in_header' => array(
					'title'   => __( 'Show Social Icons', 'wen-associate' ),
					'type'    => 'checkbox',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					),
				'search_in_header' => array(
					'title'   => __( 'Show Search Icons', 'wen-associate' ),
					'type'    => 'checkbox',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					),
				'enable_circular_icons' => array(
					'title'   => __( 'Enable Circular Icons', 'wen-associate' ),
					'type'    => 'checkbox',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					),
				'primary_menu_alignment' => array(
					'title'             => __( 'Menu Alignment', 'wen-associate' ),
					'type'              => 'select',
					'choices'           => wen_associate_get_menu_alignment_options(),
					'sanitize_callback' => 'wen_associate_sanitize_select',
					),
				'disable_sticky_primary_menu' => array(
					'title'             => __( 'Disable Sticky in Primary Menu', 'wen-associate' ),
					'type'              => 'checkbox',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					),
				),
			);

		// Layout Section.
		$args['panels']['theme_option_panel']['sections']['section_layout'] = array(
			'title'    => __( 'Layout Options', 'wen-associate' ),
			'priority' => 70,
			'fields'   => array(
				'site_layout' => array(
					'title'             => __( 'Site Layout', 'wen-associate' ),
					'type'              => 'select',
					'choices'           => wen_associate_get_site_layout_options(),
					'sanitize_callback' => 'wen_associate_sanitize_select',
					),
				'global_layout' => array(
					'title'             => __( 'Global Layout', 'wen-associate' ),
					'type'              => 'select',
					'choices'           => wen_associate_get_global_layout_options(),
					'sanitize_callback' => 'wen_associate_sanitize_select',
					),
				'archive_layout' => array(
					'title'             => __( 'Archive Layout', 'wen-associate' ),
					'type'              => 'select',
					'choices'           => wen_associate_get_archive_layout_options(),
					'sanitize_callback' => 'wen_associate_sanitize_select',
					),
				'archive_image' => array(
					'title'             => __( 'Image in Archive', 'wen-associate' ),
					'type'              => 'select',
					'choices'           => wen_associate_get_image_sizes_options(),
					'sanitize_callback' => 'wen_associate_sanitize_select',
					),
				'archive_image_alignment' => array(
					'title'             => __( 'Alignment of Image in Archive', 'wen-associate' ),
					'type'              => 'select',
					'choices'           => wen_associate_get_image_alignment_options(),
					'sanitize_callback' => 'wen_associate_sanitize_select',
					),
				'single_image' => array(
					'title'             => __( 'Image in Single Post/Page', 'wen-associate' ),
					'type'              => 'select',
					'choices'           => wen_associate_get_image_sizes_options(),
					'sanitize_callback' => 'wen_associate_sanitize_select',
					),
				'single_image_alignment' => array(
					'title'             => __( 'Alignment of Image in Single Post/Page', 'wen-associate' ),
					'type'              => 'select',
					'choices'           => wen_associate_get_image_alignment_options(),
					'sanitize_callback' => 'wen_associate_sanitize_select',
					),
				),
			);

		// Pagination Section.
		$args['panels']['theme_option_panel']['sections']['section_pagination'] = array(
			'title'    => __( 'Pagination Options', 'wen-associate' ),
			'priority' => 70,
			'fields'   => array(
				'pagination_type' => array(
					'title'             => __( 'Pagination Type', 'wen-associate' ),
					'type'              => 'select',
					'sanitize_callback' => 'sanitize_key',
					'choices'           => wen_associate_get_pagination_type_options(),
					),
				),
			);

		// Content Meta Section.
		$args['panels']['theme_option_panel']['sections']['section_content_meta'] = array(
			'title'    => __( 'Content Meta Options', 'wen-associate' ),
			'priority' => 78,
			'fields'   => array(
				'meta_show_date' => array(
					'title'             => __( 'Show Date', 'wen-associate' ),
					'type'              => 'checkbox',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					),
				'meta_show_author' => array(
					'title'             => __( 'Show Author', 'wen-associate' ),
					'type'              => 'checkbox',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					),
				'meta_footer_layout' => array(
					'title'             => __( 'Footer Meta Layout', 'wen-associate' ),
					'type'              => 'radio',
					'choices'           => wen_associate_get_meta_footer_layout_options(),
					'sanitize_callback' => 'wen_associate_sanitize_select',
					),
				'meta_show_category' => array(
					'title'             => __( 'Show Categories', 'wen-associate' ),
					'type'              => 'checkbox',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					),
				'meta_show_tag' => array(
					'title'             => __( 'Show Tags', 'wen-associate' ),
					'type'              => 'checkbox',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					),
				'meta_show_comment' => array(
					'title'             => __( 'Show Comment', 'wen-associate' ),
					'type'              => 'checkbox',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					),
				),
			);

		// Footer Section.
		$args['panels']['theme_option_panel']['sections']['section_footer'] = array(
			'title'    => __( 'Footer Options', 'wen-associate' ),
			'priority' => 80,
			'fields'   => array(
				'copyright_text' => array(
					'title' => __( 'Copyright Text', 'wen-associate' ),
					'type'  => 'textarea',
					'sanitize_callback' => 'wen_associate_sanitize_footer_content',
					),
				'powered_by_text' => array(
					'title'             => __( 'Powered By Text', 'wen-associate' ),
					'type'              => 'textarea',
					'sanitize_callback' => 'wen_associate_sanitize_footer_content',
					),
				'reset_footer_content' => array(
					'title'             => __( 'Reset Footer Content', 'wen-associate' ),
					'description'       => __( 'Save and refresh page to see effect.', 'wen-associate' ),
					'type'              => 'checkbox',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					),
				'go_to_top' => array(
					'title' => __( 'Show Go To Top', 'wen-associate' ),
					'type'  => 'checkbox',
					),
				'go_to_top_icon' => array(
					'title'             => __( 'Go To Top Icon', 'wen-associate' ),
					'description'       => __( 'Enter FontAwesome icon. Default: fa-chevron-circle-up', 'wen-associate' ),
					'type'              => 'text',
					'sanitize_callback' => 'sanitize_key',
					'active_callback'   => 'wen_associate_is_go_to_top_active',
					),
				),
			);

		// Blog Section.
		$args['panels']['theme_option_panel']['sections']['section_blog'] = array(
			'title'    => __( 'Blog Options', 'wen-associate' ),
			'priority' => 80,
			'fields'   => array(
				'excerpt_length' => array(
					'title'             => __( 'Excerpt Length', 'wen-associate' ),
					'description'       => __( 'in words', 'wen-associate' ),
					'type'              => 'text',
					'sanitize_callback' => 'wen_associate_sanitize_positive_integer',
					'input_attrs'       => array(
						'min'   => 1,
						'max'   => 200,
						'style' => 'width: 55px;',
						),
					),
				'read_more_text' => array(
					'title'             => __( 'Read More Text', 'wen-associate' ),
					'type'              => 'text',
					'sanitize_callback' => 'sanitize_text_field',
					),
				'exclude_categories' => array(
					'title'             => __( 'Exclude Categories in Blog', 'wen-associate' ),
					'description'       => __( 'Enter category ID to exclude in Blog Page. Separate with comma if more than one', 'wen-associate' ),
					'type'              => 'text',
					'sanitize_callback' => 'sanitize_text_field',
					),
				),
			);

		// Author Bio Section.
		$args['panels']['theme_option_panel']['sections']['section_author_bio'] = array(
			'title'       => __( 'Author Bio Options', 'wen-associate' ),
			'description' => __( 'Author Box will be displayed in the single post article.', 'wen-associate' ),
			'priority'    => 80,
			'fields'   => array(
				'author_bio_in_single' => array(
					'title'             => __( 'Show Author Bio', 'wen-associate' ),
					'type'              => 'checkbox',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					),
				'author_bio_show_recent_posts' => array(
					'title'             => __( 'Show Recent Posts', 'wen-associate' ),
					'type'              => 'checkbox',
					'sanitize_callback' => 'wen_associate_sanitize_checkbox',
					'active_callback'   => 'wen_associate_is_show_author_bio_active',
					),
				'author_bio_recent_posts_number' => array(
					'title'             => __( 'No of Recent Posts', 'wen-associate' ),
					'type'              => 'number',
					'sanitize_callback' => 'wen_associate_sanitize_number_range',
					'active_callback'   => 'wen_associate_is_author_bio_recent_posts_active',
					'input_attrs'       => array(
						'min'   => 1,
						'max'   => 10,
						'step'  => 1,
						'style' => 'width: 50px;',
						),
					),
				),
			);

		// Breadcrumb Section.
		$args['panels']['theme_option_panel']['sections']['section_breadcrumb'] = array(
			'title'    => __( 'Breadcrumb Options', 'wen-associate' ),
			'priority' => 80,
			'fields'   => array(
				'breadcrumb_type' => array(
					'title'             => __( 'Breadcrumb Type', 'wen-associate' ),
					'description'       => sprintf( __( 'Advanced: Requires %1$sBreadcrumb NavXT%2$s plugin', 'wen-associate' ), '<a href="https://wordpress.org/plugins/breadcrumb-navxt/" target="_blank">', '</a>' ),
					'type'              => 'select',
					'choices'           => wen_associate_get_breadcrumb_type_options(),
					'sanitize_callback' => 'sanitize_key',
					),
				),
			);

		// Font Section.
		$font_fields = array();

		$font_keys = wen_associate_get_font_family_theme_settings_options();

		if ( ! empty( $font_keys ) && is_array( $font_keys ) ) {
			$choices = wen_associate_get_customizer_font_options();
			foreach ( $font_keys as $k => $v ) {
				$font_fields[ $k ] = array(
					'title'             => $v['label'],
					'type'              => 'select',
					'choices'           => $choices,
					'sanitize_callback' => 'wen_associate_sanitize_select',
					);
			}
			// Add reset Font settings Field.
			$font_fields['reset_font_settings'] = array(
				'title'             => __( 'Reset Font Settings', 'wen-associate' ),
				'type'              => 'checkbox',
				'transport'         => 'postMessage',
				'sanitize_callback' => 'wen_associate_sanitize_checkbox',
				);
		}

		if ( ! empty( $font_fields ) ) {
			$args['panels']['theme_option_panel']['sections']['section_font_family'] = array(
				'title'    => __( 'Font Family Options', 'wen-associate' ),
				'priority' => 65,
				'fields'   => $font_fields,
				);
		}

		// Fix for Custom CSS option.
		if ( function_exists( 'wp_get_custom_css_post' ) ) {

			if ( isset( $args['panels']['theme_option_panel']['sections']['section_advanced']['fields']['custom_css'] ) ) {
				unset( $args['panels']['theme_option_panel']['sections']['section_advanced']['fields']['custom_css'] );
			}

		}

		return $args;
	}

endif;
