<?php
/**
 * Custom hooks.
 *
 * @package WEN_Associate
 */

if ( ! function_exists( 'wen_associate_custom_content_class' ) ) :

	/**
	 * Custom Primary class.
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $input One or more classes to add to the class list.
	 * @return array Array of classes.
	 */
	function wen_associate_custom_content_class( $input ) {

		global $post;
		$global_layout = wen_associate_get_option( 'global_layout' );
		$global_layout = apply_filters( 'wen_associate_filter_theme_global_layout', $global_layout );

		// Check if single.
		if ( $post  && is_singular() ) {
			$post_options = get_post_meta( $post->ID, 'theme_settings', true );
			if ( isset( $post_options['post_layout'] ) && ! empty( $post_options['post_layout'] ) ) {
				$global_layout = $post_options['post_layout'];
			}
		}

		$new_class = '';

		switch ( $global_layout ) {
			case 'left-sidebar':
			case 'right-sidebar':
				$new_class = 'col-sm-8';
			break;

			case 'three-columns':
			case 'three-columns-pcs':
			case 'three-columns-cps':
			case 'three-columns-psc':
				$new_class = 'col-sm-6';
			break;

			case 'three-columns-pcs-equal':
			case 'three-columns-scp-equal':
				$new_class = 'col-sm-4';
			break;

			case 'no-sidebar':
				$new_class = 'col-sm-12';
			break;

			case 'no-sidebar-centered':
				$new_class = 'col-sm-6';
			break;

			default:
			break;
		}

		if ( ! empty( $new_class ) ) {
			$input[] = $new_class;
		}

		return $input;
	}
endif;
add_filter( 'wen_associate_filter_content_class', 'wen_associate_custom_content_class' );


if ( ! function_exists( 'wen_associate_custom_sidebar_primary_class' ) ) :

	/**
	 * Custom Sidebar Primary class.
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $input One or more classes to add to the class list.
	 * @return array Array of classes.
	 */
	function wen_associate_custom_sidebar_primary_class( $input ) {

		global $post;
		$global_layout = wen_associate_get_option( 'global_layout' );
		$global_layout = apply_filters( 'wen_associate_filter_theme_global_layout', $global_layout );

		// Check if single.
		if ( $post && is_singular() ) {
			$post_options = get_post_meta( $post->ID, 'theme_settings', true );
			if ( isset( $post_options['post_layout'] ) && ! empty( $post_options['post_layout'] ) ) {
				$global_layout = $post_options['post_layout'];
			}
		}

		$new_class = '';

		switch ( $global_layout ) {
			case 'three-columns':
			case 'three-columns-pcs':
			case 'three-columns-cps':
			case 'three-columns-psc':
				$new_class = 'col-sm-3';
				break;

			case 'three-columns-pcs-equal':
			case 'three-columns-scp-equal':
				$new_class = 'col-sm-4';
				break;

			case 'left-sidebar':
			case 'right-sidebar':
				$new_class = 'col-sm-4';
				break;

			default:
				break;
		}

		if ( ! empty( $new_class ) ) {
			$input[] = $new_class;
		}

		return $input;
	}
endif;
add_filter( 'wen_associate_filter_sidebar_primary_class', 'wen_associate_custom_sidebar_primary_class' );


if ( ! function_exists( 'wen_associate_custom_sidebar_secondary_class' ) ) :

	/**
	 * Custom Sidebar Secondary class.
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $input One or more classes to add to the class list.
	 * @return array Array of classes.
	 */
	function wen_associate_custom_sidebar_secondary_class( $input ) {

		global $post;
		$global_layout = wen_associate_get_option( 'global_layout' );
		$global_layout = apply_filters( 'wen_associate_filter_theme_global_layout', $global_layout );

		// Check if single.
		if ( $post  && is_singular() ) {
			$post_options = get_post_meta( $post->ID, 'theme_settings', true );
			if ( isset( $post_options['post_layout'] ) && ! empty( $post_options['post_layout'] ) ) {
				$global_layout = $post_options['post_layout'];
			}
		}

		$new_class = '';

		switch ( $global_layout ) {
			case 'three-columns':
			case 'three-columns-pcs':
			case 'three-columns-cps':
			case 'three-columns-psc':
				$new_class = 'col-sm-3';
			break;

			case 'three-columns-pcs-equal':
			case 'three-columns-scp-equal':
				$new_class = 'col-sm-4';
			break;

			default:
			break;
		}

		if ( ! empty( $new_class ) ) {
			$input[] = $new_class;
		}

		return $input;
	}
endif;

add_filter( 'wen_associate_filter_sidebar_secondary_class', 'wen_associate_custom_sidebar_secondary_class' );

if ( ! function_exists( 'wen_associate_implement_front_page_widget_area' ) ) :

	/**
	 * Implement front page widget area.
	 *
	 * @since WEN Associate 1.0
	 */
	function wen_associate_implement_front_page_widget_area() {

	?>
      <div id="sidebar-front-page-main" class="widget-area">
	    <?php if ( is_active_sidebar( 'sidebar-front-page-main' ) ) : ?>

	        <?php dynamic_sidebar( 'sidebar-front-page-main' ); ?>

	    <?php else : ?>

	    	<?php if ( current_user_can( 'administrator' ) ) : ?>
	    		<?php
	    		$args = array(
					'title' => __( 'Welcome', 'wen-associate' ),
					'text'  => __( "You are viewing this because there is no any widgets to be displayed in front page. Please add widgets in 'Front Page : Main'. Other widget areas available for front page are 'Front Page : Lower Left', 'Front Page : Lower Right' and 'Front Page : Bottom'. Go to Appearance->Widgets in admin panel to add widgets.", 'wen-associate' ),
	    		);
	    		$widget_args = array(
					'before_title' => '<h3 class="widget-title">',
					'after_title'  => '</h3>',
	    		);
	    		the_widget( 'WP_Widget_Text', $args, $widget_args );
	    		?>
	    	<?php endif; ?>

	    <?php endif; ?>
      </div><!-- #sidebar-front-page-main -->
    <?php if ( is_active_sidebar( 'sidebar-front-page-lower-left' ) || is_active_sidebar( 'sidebar-front-page-lower-right' ) ) :  ?>
      <div id="sidebar-front-page-lower">
        <div class="row">
          <div class="col-sm-8">
            <div id="sidebar-front-page-lower-left">
				<?php dynamic_sidebar( 'sidebar-front-page-lower-left' ); ?>
            </div><!-- #sidebar-front-page-lower-left -->
          </div><!-- .col-sm-8 -->
          <div class="col-sm-4">
            <div id="sidebar-front-page-lower-right">
				<?php dynamic_sidebar( 'sidebar-front-page-lower-right' ); ?>
            </div><!-- #sidebar-front-page-lower-right -->
            </div><!-- .col-sm-4 -->
        </div><!-- .row -->
      </div><!-- #sidebar-front-page-lower -->
    <?php endif ?>
    <?php

	}

endif;

add_action( 'wen_associate_action_front_page', 'wen_associate_implement_front_page_widget_area' );


if ( ! function_exists( 'wen_associate_add_front_bottom_widget_area' ) ) :

	/**
	 * Add front bottom widget area.
	 *
	 * This widget area is displayed only when static front page is set.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_add_front_bottom_widget_area() {

		global $wp_query;

		// Get Page ID outside Loop.
		$page_id = $wp_query->get_queried_object_id();

		// Front page displays in Reading Settings.
		$page_on_front  = get_option( 'page_on_front' );

		if ( absint( $page_on_front ) > 0 && ( absint( $page_id ) === absint( $page_on_front ) ) ) {
			?>
  		<?php if ( is_active_sidebar( 'sidebar-front-page-bottom' ) ) : ?>
  		  <div id="sidebar-front-page-bottom" class="widget-area">
  		    <div class="container">
  		    <?php dynamic_sidebar( 'sidebar-front-page-bottom' ); ?>
  		    </div><!-- .container -->
  		  </div><!-- #sidebar-front-page-bottom -->
  		<?php endif ?>
  		<?php
		}
	}
endif;

add_action( 'wen_associate_action_before_footer', 'wen_associate_add_front_bottom_widget_area', 2 );

if ( ! function_exists( 'wen_associate_add_author_bio_in_single' ) ) :

	/**
	 * Display Author bio in single blog post.
	 *
	 * @since WEN Associate 1.0
	 */
	function wen_associate_add_author_bio_in_single() {

		if ( is_singular( 'post' ) ) {
			$author_bio_in_single = wen_associate_get_option( 'author_bio_in_single' );
			if ( 1 != $author_bio_in_single ) {
				return;
			}
			get_template_part( 'template-parts/single-author', 'bio' );
		}

	}
endif;

add_action( 'wen_associate_author_bio', 'wen_associate_add_author_bio_in_single' );


if ( ! function_exists( 'wen_associate_site_branding' ) ) :

	/**
	 * Site branding
	 *
	 * @since  WEN Associate 1.0
	 */
	function wen_associate_site_branding() {

	?>
	<div class="site-branding">

		<?php wen_associate_the_custom_logo(); ?>

		<?php
		$show_site_title = wen_associate_get_option( 'show_site_title' );
		$show_tagline    = wen_associate_get_option( 'show_tagline' );
		?>
		<?php if ( 1 == $show_site_title || 1 == $show_tagline ) : ?>
			<div class="site-identity">
				<?php if ( 1 == $show_site_title ) : ?>
					<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
						<?php bloginfo( 'name' ); ?>
					</a></h1>
				<?php endif; ?>
				<?php if ( 1 == $show_tagline ) :  ?>
					<h2 class="site-description"><?php bloginfo( 'description' ); ?></h2>
				<?php endif; ?>
			</div><!-- .site-identity -->
		<?php endif; ?>

	</div><!-- .site-branding -->

	<?php
	$social_in_header      = wen_associate_get_option( 'social_in_header' );
	$search_in_header      = wen_associate_get_option( 'search_in_header' );
	$enable_circular_icons = wen_associate_get_option( 'enable_circular_icons' );
	?>
    <?php if ( ( 1 == $social_in_header && wen_associate_is_social_menu_active() ) || 1 == $search_in_header ) :  ?>

    	<aside class="sidebar-header-right">

    		<?php if ( 1 == $social_in_header && wen_associate_is_social_menu_active() ) :  ?>
    			<?php
    				$soc_args = array(
    					'icon_design' => ( true === $enable_circular_icons ) ? 'circle' : '',
    					);
    			 ?>
    			<?php the_widget( 'WEN_Associate_Social_Widget', $soc_args ); ?>
    		<?php endif ?>

    		<?php if ( 1 == $search_in_header ) :  ?>

    			<?php
	    			$search_design_class = ( true === $enable_circular_icons ) ? 'search-circle' : '';
    			 ?>
    			<div class="search-btn-wrap <?php echo esc_attr( $search_design_class ); ?>"><a href="#" id="btn-search-icon"><i class="fa fa-search"></i></a></div><!-- .search-btn-wrap -->
    			<div id="header-search-form">
    				<?php get_search_form(); ?>
    			</div><!-- #header-search-form -->

    		<?php endif ?>
    	</aside><!-- .sidebar-header-right -->

    <?php endif ?>

    <?php

	}

endif;
add_action( 'wen_associate_action_header', 'wen_associate_site_branding' );


if ( ! function_exists( 'wen_associate_primary_navigation' ) ) :

	/**
	 * Primary navigation
	 *
	 * @since  WEN Associate 1.0
	 */
	function wen_associate_primary_navigation() {

	?>
    <div id="site-navigation" role="navigation">
      <div class="container">
      	<?php
	      	$menu_class = array( 'menu' );
	      	$menu_class[] = 'menu-align-' . esc_attr( wen_associate_get_option( 'primary_menu_alignment' ) );
	      	wp_nav_menu( array(
	      		'theme_location'  => 'primary',
	      		'container'       => 'nav',
	      		'container_class' => 'main-navigation',
	      		'fallback_cb'     => 'wen_associate_primary_navigation_fallback',
				'menu_class'      => implode( ' ', $menu_class ),
	      		)
	      	);
	  	?>
      </div><!-- .container -->
    </div><!-- #site-navigation -->
    <?php

	}

endif;
add_action( 'wen_associate_action_after_header', 'wen_associate_primary_navigation', 50 );


if ( ! function_exists( 'wen_associate_mobile_navigation' ) ) :

	/**
	 * Primary navigation.
	 *
	 * @since  WEN Associate 1.0
	 */
	function wen_associate_mobile_navigation() {
	?>
	    <a id="mobile-trigger" href="#mob-menu"><i class="fa fa-bars"></i></a>
	    <div id="mob-menu">
			<?php
	        wp_nav_menu( array(
				'theme_location' => 'primary',
				'container'      => '',
				'fallback_cb'    => 'wen_associate_primary_navigation_fallback',
	        ) );
			?>
	    </div><!-- #mob-menu -->
    <?php

	}

endif;
add_action( 'wen_associate_action_before', 'wen_associate_mobile_navigation', 20 );


if ( ! function_exists( 'wen_associate_add_image_in_single_display' ) ) :

	/**
	 * Add image in single post.
	 *
	 * @since  WEN Associate 1.0
	 */
	function wen_associate_add_image_in_single_display() {

		global $post;

		if ( has_post_thumbnail() ) {

			$values = get_post_meta( $post->ID, 'theme_settings', true );
			$theme_settings_single_image = isset( $values['single_image'] ) ? esc_attr( $values['single_image'] ) : '';
			$theme_settings_single_image_alignment = isset( $values['single_image_alignment'] ) ? esc_attr( $values['single_image_alignment'] ) : '';

			if ( ! $theme_settings_single_image ) {
				$theme_settings_single_image = wen_associate_get_option( 'single_image' );
			}
			if ( ! $theme_settings_single_image_alignment ) {
				$theme_settings_single_image_alignment = wen_associate_get_option( 'single_image_alignment' );
			}

			if ( 'disable' !== $theme_settings_single_image ) {
				$args = array(
					'class' => 'align' . $theme_settings_single_image_alignment,
				);
				the_post_thumbnail( $theme_settings_single_image, $args );
			}
		}

	}

endif;
add_action( 'wen_associate_single_image', 'wen_associate_add_image_in_single_display' );


if ( ! function_exists( 'wen_associate_custom_posts_navigation' ) ) :

	/**
	 * Posts navigation.
	 *
	 * @since WEN Associate 1.0
	 */
	function wen_associate_custom_posts_navigation() {

		$pagination_type = wen_associate_get_option( 'pagination_type' );

		switch ( $pagination_type ) {

			case 'default':
				the_posts_navigation();
				break;

			case 'numeric':
				the_posts_pagination();
				break;

			default:
				break;
		}

	}
endif;
add_action( 'wen_associate_action_posts_navigation', 'wen_associate_custom_posts_navigation' );


if ( ! function_exists( 'wen_associate_footer_copyright' ) ) :

	/**
	 * Footer copyright.
	 *
	 * @since  WEN Associate 1.0
	 */
	function wen_associate_footer_copyright() {

		// Check if footer is disabled.
		$footer_status = apply_filters( 'wen_associate_filter_footer_status', true );
		if ( true !== $footer_status ) {
			return;
		}

		// Copyright.
		$copyright_text = wen_associate_get_option( 'copyright_text' );
		$copyright_text = apply_filters( 'wen_associate_filter_copyright_text', $copyright_text );
		if ( ! empty( $copyright_text ) ) {
			$copyright_text = wp_kses_data( $copyright_text );
			$copyright_text = wen_associate_apply_theme_shortcode( $copyright_text );
		}

		// Powered By.
		$powered_by_text = wen_associate_get_option( 'powered_by_text' );
		$powered_by_text = apply_filters( 'wen_associate_filter_powered_by_text', $powered_by_text );
		if ( ! empty( $powered_by_text ) ) {
			$allowed_tags = wp_kses_allowed_html( 'post' );
			$powered_by_text = wp_kses( $powered_by_text, $allowed_tags );
			$powered_by_text = wen_associate_apply_theme_shortcode( $powered_by_text );
		}

		// Footer navigation.
		$footer_menu_content = wp_nav_menu( array(
			'theme_location' => 'footer',
			'container'      => 'div',
			'container_id'   => 'footer-navigation',
			'depth'          => 1,
			'fallback_cb'    => false,
			'echo'           => false,
		) );

	?>
	<div class="row">

		<?php if ( ! empty( $footer_menu_content ) || ! empty( $copyright_text ) ) :  ?>
			<div class="col-sm-6">
				<?php if ( ! empty( $footer_menu_content ) ) :  ?>
					<?php echo $footer_menu_content; ?>
				<?php endif ?>
				<?php if ( ! empty( $copyright_text ) ) :  ?>
					<div class="copyright">
						<?php echo $copyright_text; ?>
					</div><!-- .copyright -->
				<?php endif ?>
			</div><!-- .col-sm-6 -->
		<?php endif ?>

		<div class="col-sm-6 pull-right">

			<div class="site-info">
				<?php echo $powered_by_text; ?>
			</div><!-- .site-info -->

		</div><!-- .col-sm-6 -->
	</div><!-- .row -->

    <?php

	}

endif;

add_action( 'wen_associate_action_footer', 'wen_associate_footer_copyright', 10 );


if ( ! function_exists( 'wen_associate_footer_goto_top' ) ) :

	/**
	 * Add Go to top markup.
	 *
	 * @since  WEN Associate 1.0
	 */
	function wen_associate_footer_goto_top() {

		$go_to_top = wen_associate_get_option( 'go_to_top' );
		$go_to_top_icon = wen_associate_get_option( 'go_to_top_icon' );
		if ( 1 != $go_to_top || empty( $go_to_top_icon ) ) {
			return;
		}
		echo '<a href="#" class="scrollup" id="btn-scrollup"><i class="fa ' . esc_attr( $go_to_top_icon ) . '"></i></a>';

	}

endif;

add_action( 'wen_associate_action_after', 'wen_associate_footer_goto_top', 20 );

if ( ! function_exists( 'wen_associate_add_sidebar' ) ) :

	/**
	 * Add sidebar.
	 *
	 * @since  WEN Associate 1.0
	 */
	function wen_associate_add_sidebar() {

		global $post;

		$global_layout = wen_associate_get_option( 'global_layout' );
		$global_layout = apply_filters( 'wen_associate_filter_theme_global_layout', $global_layout );

		// Check if single.
		if ( $post && is_singular() ) {
			$post_options = get_post_meta( $post->ID, 'theme_settings', true );
			if ( isset( $post_options['post_layout'] ) && ! empty( $post_options['post_layout'] ) ) {
				$global_layout = $post_options['post_layout'];
			}
		}

		// Include sidebar.
		if ( ! in_array( $global_layout, array( 'no-sidebar', 'no-sidebar-centered' ) ) ) {
			$sidebar = apply_filters( 'wen_associate_filter_select_primary_sidebar', '' );
			get_sidebar( $sidebar );
		}

		switch ( $global_layout ) {
			case 'three-columns':
			case 'three-columns-pcs':
			case 'three-columns-cps':
			case 'three-columns-psc':
			case 'three-columns-pcs-equal':
			case 'three-columns-scp-equal':
				$sidebar = apply_filters( 'wen_associate_filter_select_secondary_sidebar', 'secondary' );
				get_sidebar( $sidebar );
				break;

			default:
				break;
		}

	}

endif;
add_action( 'wen_associate_action_sidebar', 'wen_associate_add_sidebar' );

if ( ! function_exists( 'wen_associate_add_breadcrumb' ) ) :

	/**
	 * Add breadcrumb.
	 *
	 * @since  WEN Associate 1.0
	 */
	function wen_associate_add_breadcrumb() {

		// Bail if Breadcrumb disabled.
		$breadcrumb_type = wen_associate_get_option( 'breadcrumb_type' );
		if ( 'disabled' === $breadcrumb_type ) {
			return;
		}
		// Bail if Home Page.
		if ( is_front_page() || is_home() ) {
			return;
		}

		echo '<div id="breadcrumb"><div class="container">';
		switch ( $breadcrumb_type ) {
			case 'simple':
				wen_associate_simple_breadcrumb();
				break;

			case 'advanced':
				if ( function_exists( 'bcn_display' ) ) {
					bcn_display();
				}
				break;

			default:
				break;
		}
		echo '</div><!-- .container --></div><!-- #breadcrumb -->';
		return;

	}

endif;

add_action( 'wen_associate_action_before_content', 'wen_associate_add_breadcrumb' , 7 );

if ( ! function_exists( 'wen_associate_primary_navigation_fallback' ) ) :

	/**
	 * Fallback for primary navigation.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_primary_navigation_fallback() {
		echo '<ul>';
		echo '<li><a href="' . esc_url( home_url( '/' ) ) . '">' . __( 'Home', 'wen-associate' ). '</a></li>';
		wp_list_pages( array(
			'title_li' => '',
			'depth'    => 1,
			'number'   => 7,
		) );
		echo '</ul>';

	}

endif;


if ( ! function_exists( 'wen_associate_add_top_header' ) ) :

	/**
	 * Add top header.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_add_top_header() {
		$enable_top_bar = wen_associate_get_option( 'enable_top_bar' );
		if ( true !== $enable_top_bar ) {
			return;
		}
		$contact_number = wen_associate_get_option( 'contact_number' );
		$contact_email  = wen_associate_get_option( 'contact_email' );
		$quick_menu = wp_nav_menu(
			array(
				'theme_location' => 'quick-links',
				'depth'          => 1,
				'echo'           => false,
				'fallback_cb'    => false,
			)
		);
		if ( empty( $contact_number ) && empty( $contact_email ) && empty( $quick_menu ) ) {
			return;
		}

		?>
		<div id="tophead">
			<div class="container">
				<?php if ( ! empty( $contact_number ) || ! empty( $contact_email ) ) : ?>
					<div id="quick-contact">
						<ul>
							<?php if ( ! empty( $contact_number ) ) : ?>
								<li class="quick-call"><a href="tel:<?php echo preg_replace( '/\D+/', '', esc_attr( $contact_number ) ); ?>"><?php echo esc_attr( $contact_number ); ?></a></li>
							<?php endif ?>
							<?php if ( ! empty( $contact_email ) ) : ?>
								<li class="quick-email"><a href="mailto:<?php echo esc_attr( $contact_email ); ?>"><?php echo esc_attr( antispambot( $contact_email ) ); ?></a></li>
							<?php endif ?>
						</ul>
					</div><!--  #quick-contact -->
				<?php endif ?>
				<?php if ( ! empty( $quick_menu ) ) : ?>
					<div id="quick-links">
						<?php echo $quick_menu; ?>
					</div><!--  #quick-links -->
				<?php endif ?>
			</div><!-- .container -->
		</div><!-- #tophead -->
		<?php
	}

endif;

add_action( 'wen_associate_action_before_header', 'wen_associate_add_top_header', 5 );



if ( ! function_exists( 'wen_associate_show_default_message_sidebar' ) ) :

	/**
	 * Add default message in sidebar.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_show_default_message_sidebar( $default_sidebar, $sidebar_location ) {
		?>
		<?php if ( current_user_can( 'administrator' ) ) : ?>
			<?php
			$args = array(
				'title' => ucfirst( $sidebar_location ),
				'text'  => __( "This is just placeholder widget. Please go to 'Appearance' &rarr; 'Widgets' in admin panel to add widgets.", 'wen-associate' ),
				);
			$widget_args = array(
				'before_title' => '<h3 class="widget-title">',
				'after_title'  => '</h3>',
				);
			the_widget( 'WP_Widget_Text', $args, $widget_args );
			?>
		<?php endif; ?>
		<?php
	}
endif;

add_action( 'wen_associate_action_default_sidebar', 'wen_associate_show_default_message_sidebar', 10, 2 );
